maybe_auto_fund

Function maybe_auto_fund 

async fn maybe_auto_fund(
    used: &AtomicBool,
    ctx: &FundingContext,
) -> TransportResult<bool>
Single-attempt guard around run_interactive_tempo_fund.

Ensures that for one logical request we launch tempo wallet fund at most once, regardless of how many recovery paths (do_request, pay_and_retry, handle_response_or_retry_after_fund, …) attempt it.