pub struct MppHttpTransport<P> {
client: Client,
url: Url,
provider: P,
}Expand description
HTTP transport with automatic MPP (Machine Payments Protocol) 402 handling.
Generic over the payment provider P. Works as a normal HTTP transport until
a 402 Payment Required response is received, then delegates payment to P.
Fields
client: Clienturl: Urlprovider: PImplementations
Sourceimpl<P> MppHttpTransport<P>
impl<P> MppHttpTransport<P>
Sourceimpl<P: ResolveProvider + Clone + Send + Sync + 'static> MppHttpTransport<P>
impl<P: ResolveProvider + Clone + Send + Sync + 'static> MppHttpTransport<P>
async fn do_request(self, req: RequestPacket) -> TransportResult<ResponsePacket>
Sourceasync fn pay_and_retry(
&self,
challenge: &PaymentChallenge,
provider: &P::Provider,
headers: &HeaderMap,
body: &[u8],
) -> TransportResult<Response>
async fn pay_and_retry( &self, challenge: &PaymentChallenge, provider: &P::Provider, headers: &HeaderMap, body: &[u8], ) -> TransportResult<Response>
Pay a challenge and send the authenticated retry request.
Sourceasync fn fetch_fresh_challenge(
&self,
headers: &HeaderMap,
body: &[u8],
) -> TransportResult<(P::Provider, PaymentChallenge)>
async fn fetch_fresh_challenge( &self, headers: &HeaderMap, body: &[u8], ) -> TransportResult<(P::Provider, PaymentChallenge)>
Fetch a fresh 402 challenge from the server (unauthenticated request).
Returns Ok(Some((provider, challenge))) if the server returns a 402
with a matching challenge. Returns Ok(None) with the response handled
if the server returns a non-402 status. Errors on network or parse failures.
Sourcefn select_challenge(
resp: &Response,
provider: &P,
) -> TransportResult<(P::Provider, PaymentChallenge)>
fn select_challenge( resp: &Response, provider: &P, ) -> TransportResult<(P::Provider, PaymentChallenge)>
Parse WWW-Authenticate challenges from a 402 response and resolve
the first one matching a locally configured key (chain + currency).
async fn handle_response(resp: Response) -> TransportResult<ResponsePacket>